#
# spec file for package libmicrohttpd
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010,2011,2012  Stephan Kleine
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sover   12
%global libname %{name}%{sover}
Name:           libmicrohttpd
Version:        0.9.57
Release:        1.33
Summary:        Small Embeddable HTTP Server Library
# Some internal tests are licenced as GPL-3.0+ - they are only used in
# check phase and not shipped further
License:        LGPL-2.1+ AND GPL-3.0+
Group:          Productivity/Networking/Web/Servers
Url:            https://www.gnu.org/software/libmicrohttpd/
Source0:        https://ftp.gnu.org/gnu/libmicrohttpd/%{name}-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/libmicrohttpd/%{name}-%{version}.tar.gz.sig
Source2:        https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=%{name}&download=1#/%{name}.keyring
BuildRequires:  curl
BuildRequires:  file-devel
BuildRequires:  libgcrypt-devel >= 1.2.4
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  socat
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libtasn1)

%description
GNU libmicrohttpd is a small C library that is supposed to make it easy to run
an HTTP server as part of another application. GNU libmicrohttpd is free software
and part of the GNU project. Key features that distinguish libmicrohttpd from
other projects are:

    * C library: fast and small
    * API is simple, expressive and fully reentrant
    * Implementation is http 1.1 compliant
    * HTTP server can listen on multiple ports
    * Support for IPv6
    * Support for incremental processing of POST data
    * Creates binary of only 30k (without TLS/SSL support)
    * Three different threading models
    * Supported platforms include GNU/Linux, FreeBSD, OpenBSD, NetBSD, OS X, W32,
      Symbian and z/OS
    * Optional support for SSL3 and TLS (requires libgcrypt)

libmicrohttpd was started because the author needed an easy way to add a concurrent
HTTP server to other projects. Existing alternatives were either non-free, not
reentrant, standalone, of terrible code quality or a combination thereof. Do not
use libmicrohttpd if you are looking for a standalone http server, there are many
other projects out there that provide that kind of functionality already. However,
if you want to be able to serve simple WWW pages from within your C or C++
application, check it out.

%package -n %{libname}
Summary:        Small embeddable http server library
License:        LGPL-2.1+
Group:          System/Libraries

%description -n %{libname}
Shared library for %{name} (%{summary}).

%package devel
Summary:        Small Embeddable HTTP Server Library
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(gnutls)
Requires(post): info
Requires(preun): info

%description devel
Headers, pkg-config files, so link and other development files for %{name}
(%{summary}).

%prep
%setup -q

%build
%configure \
  --enable-bauth \
  --enable-dauth \
  --enable-epoll \
  --enable-messages \
  --enable-postprocessor \
  --enable-https \
  --disable-static \
  --disable-examples \
  --enable-curl
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
# Paralel execution of tests fail
# Tests randomly fail so keep them in log for inspection rather than for valid
# verification of anything.
make -j1 check || :

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig
%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/libmicrohttpd.info%{ext_info}
%install_info --info-dir=%{_infodir} %{_infodir}/libmicrohttpd-tutorial.info%{ext_info}

%preun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libmicrohttpd.info%{ext_info}
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libmicrohttpd-tutorial.info%{ext_info}

%files -n %{libname}
%doc COPYING
%{_libdir}/%{name}.so.%{sover}*

%files devel
%doc ChangeLog
%{_includedir}/microhttpd.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_infodir}/%{name}*.info%{ext_info}
%{_mandir}/man3/%{name}.3%{ext_man}

%changelog
* Fri Dec  1 2017 tchvatal@suse.com
- Install copying
* Thu Nov 30 2017 mpluskal@suse.com
- Update to version 0.9.57:
  * See provided Changelog for details
- Drop no longer needed patches:
  * libmicrohttpd_test_data.patch
  * disable-stalling-test.patch
* Mon May 29 2017 tchvatal@suse.com
- Version update to 0.9.55 bsc#1041216:
  * See provided Changelog for details
* Mon May 15 2017 mpluskal@suse.com
- Update licensing information
* Thu May 11 2017 mpluskal@suse.com
- Update to version 0.9.54:
  * See provided Changelog for details
* Thu Apr 13 2017 mpluskal@suse.com
- Update to version 0.9.53:
  * See provided Changelog for details
- Refresh patch:
  * libmicrohttpd_test_data.patch
* Wed Mar  8 2017 tchvatal@suse.com
- Do not abort on failing tests, as they randomly fail quite a lot
  bsc#1012840
* Mon Dec 12 2016 tchvatal@suse.com
- Version update to 0.9.52:
  * See provided Changelog for details
- Refresh patch:
  * disable-stalling-test.patch
* Fri Jun  3 2016 mpluskal@suse.com
- Update to version 0.9.50:
  * See provided Changelog for details
* Thu Apr 14 2016 mpluskal@suse.com
- Update to 0.9.49
  * See provided Changelog for details
- Fix typo in previous changelog entry
- Refresh patches
- Use pkgconfig style dependencies
* Sun Dec 20 2015 mpluskal@suse.com
- Update to 0.9.48
  * Improved compatibility with VS2010 and other older compilers.
  * Default backlog size for listen socket was changed from 32 to
  SOMAXCONN, added new option MHD_OPTION_LISTEN_BACKLOG_SIZE to
  override default backlog size.
  * If not all connections can be handled by MHD_select() than at
  least some of connections will be processed instead of failing
  without any processing.
  * Fixed redefenition of FD_SETSIZE on W32 so select() will work
  with 2000 connections instead of 64.
  * Better handled redefenition of FD_SETSIZE on all platforms.
  * Close sockets more aggressively in multi-threaded mode
  (possibly relevant for idle servers).
- Update dependencies
* Sat Dec  5 2015 mpluskal@suse.com
- Update to 0.9.47
  * Reworked VS project files. Used x64 build tools by
  efault, many optimizations, fixes.
  dded project files for VS 2015. -EG
  * SPDY is dead, killing experimental libmicrospdy. -CG
  * New logic for controlling socket buffer modes.
  Eliminated delay before last packet in response and before
  "100 Continue" response on all platforms. Also response
  header are pushed to client without waiting for response
  body. -EG
  * Remove 200ms delay observable with keep-alive on Darwin
  and *BSD platfroms. -EG
  * Fix issue with shutdown if connection was resumed just
  before shutdown. -FC
- Update dependencies
* Fri Nov 13 2015 mpluskal@suse.com
- Enable http2/spdy
- Don't build examples as we don't ship them anyway
- Disable tests as linking fails for them with spdy enabled
* Tue Nov 10 2015 mpluskal@suse.com
- Update to 0.9.46
  * Undoing change from Sun Oct 25 15:29:23 CET 2015 as the
  original code was counter-intuitive but correct, and the new
  code does break pipelining. Ignore empty lines at the beginning
  of an HTTP request (more tolerant implementation).
* Sun Nov  1 2015 mpluskal@suse.com
- Update to 0.9.45
  * Rework deprecation maros: fix errors with old GCC versions,
  improved support for old clang and new GCC. -EG
  * Return correct header kind in MHD_get_connection_values()
    even if a bitmask is used for the "kind" argument. -FC/CG
  * Fixing transient resource leak affecting long-lived
    connections with many keep-alives and HTTP request
    pipelining under certain circumstances (which reduced
    the receive window).
  * Fixed assertion failure triggered by a race in
    thread-per-connection mode on shutdown in rare
    circumstances. -CG
  * Deduplicate code between digestauth and connection
    parsing logic for URI arguments, shared code moved
    to new MHD_parse_arguments_ function in internal.c. -CG
* Fri Oct  2 2015 mpluskal@suse.com
- Update to 0.9.44
  * Various fixes for W32 VS project files.
  * Fix digest authentication with URL arguments where value-less
    keys are given before the last argument.
  * Do not use shutdown() on listen socket if
    MHD_USE_PIPE_FOR_SHUTDOWN is set.
* Sat Sep 19 2015 mpluskal@suse.com
- Update to 0.9.43
  * Call resume_suspended_connections() when the user is running
    its own mainloop and calls MHD_run_from_select() to support
    resuming connections with external select. -FC
  * Correct documentation as to when MHD_USE_EPOLL_LINUX_ONLY
    is allowed. -CG
  * Reimplement monotonic clock functions for better
    support various platforms.
    Print more information during configure. -EG
  * Export MHD_get_reason_phrase_for() symbol. -CG
  * Added checks for overflows and buffer overruns, fixed
    possible buffer overrun. Updated md5 implementation.
    Fixed many compiler warning (mostly for VC compiler). -EG
  * Fix failure to properly clean up timed out connections
    if running in external select mode without listen socket,
    which caused busy waiting until new connections arrived.
    (Fixes #3924, thanks to slimp for reporting and testcase). -CG
  * Ignore close() errors on sockets except for EBADF,
    fixes #3926. -CG
  * Make sure to decrement connection counter before
    calling connection notifier so that
    MHD_DAEMON_INFO_CURRENT_CONNECTIONS does not
    present stale information (relevant if this is
    used for termination detection of a daemon
    stopped via MHD_quiesce_daemon()). Thanks to
    Markus Doppelbauer for reporting. -CG
  * Fix (automatic) handling of HEAD requests with
    MHD_create_response_from_callback() and HTTP/1.1
    connection keep-alives. Thanks to Cristian Klein
    for reporting. -CG
  * Add new functions MHD_create_response_from_fd64() and
    MHD_create_response_from_fd_at_offset64(). -EG
  * Fixing memory leak in digest authentication. -AW
  * Add deprecation compiler messages for deprecated functions
    and macros. -EG
  * Fixing digest authentication when used in combination
    with escaped characters in URLs. -CG/AW
- Disable spdy support for now as spdylay is missing
- Drop libmicrohttpd_test_session.patch as it is fixed now
* Wed Jul 15 2015 matwey.kornilov@gmail.com
- fux build for SLES11:
  * explicitly require libgnutls-devel in -devel package
* Mon Jul 13 2015 matwey.kornilov@gmail.com
- fix build for SLES11:
  * update disable-stalling-test.patch: Instead of disabling testcase
  in Makefile disable testcases in code, this could be even better
  we can disable only broken test but not the whole testcase.
  * add libmicrohttpd_test_session.patch: Disable test relying on
  available libcurl version
  (see https://gnunet.org/bugs/view.php?id=3893 for details)
  * wrap libmicrosdpy into macro to disable building on
  systems with openssl < 1.0.1
- update to 0.9.42:
  * fix off-by-one in MHD_start_daemon_va() error handling logic
  * fix #3784: actually implement MHD_CONNECTION_INFO_SOCKET_CONTEXT
* Sun May  3 2015 astieger@suse.com
- update to 0.9.41:
  * fix bugs relating to various threading modes
  * fix some HTTP 1.0 tests
* Mon Apr 13 2015 meissner@suse.com
- updated to 0.9.40
  - Fix potential deadlock issue in MHD_USE_THREAD_PER_CONNECTION
    mode if shutdown is initiated while connections are active. -CG
  - Fix issue in thread-pool mode where a MHD_stop_daemon()
    might not reach threads that stopped listening because
    we hit the maximum number of concurrent connections and
    the option MHD_USE_PIPE_FOR_SHUTDOWN was also not used.
    Testcase added as well. -CG
  - Update HTTPS testcases to avoid SSLv3, as SSLv3 is dead.
  - Do not enforce FD_SETSIZE-limit on worker control
    pipe when using MHD_USE_EPOLL_LINUX_ONLY (#3751). -MH/CG
  - Adding MHD_OPTION_NOTIFY_CONNECTION,
    MHD_CONNECTION_NOTIFY_STARTED,
    MHD_CONNECTION_NOTIFY_CLOSED and
    MHD_CONNECTION_INFO_SOCKET_CONTEXT to allow
    applications to trigger operations when TCP
    connections start or end, instead of just
    exposing HTTP requests starting and ending. -RG/CG
  - Fixing bug that prevented MHD_OPTION_HTTPS_MEM_DHPARAMS
    from working within a MHD_OPTION_ARRAY. -DD
  - Adding MHD_OPTION_HTTPS_KEY_PASSWORD as proposed by
    Andrew Basile. -CG/AB
  - Fix issue where for HTTP/1.0-clients that set
    Connection: Keep-Alive header a response of
    indefinite size was generated with chunked encoding. -CG
  - Fix potential infinite loop on shutdown in multi-threaded mode
    under certain conditions. -CG
- fixed info deinstall
* Thu Jan  8 2015 meissner@suse.com
- libmicrohttpd.keyring: replaced maintainers keyring by new one with:
  pub  4096R/E29FC3CC 2014-12-09
  uid                            Christian Grothoff <grothoff@gnunet.org>
  uid                            Christian Grothoff <christian@grothoff.org>
  uid                            Christian Grothoff <christian.grothoff@inria.fr>
  sub  4096R/117E1AFB 2014-12-09
* Wed Jan  7 2015 prusnak@opensuse.org
- updated to 0.9.39
- dropped libmicrohttpd-0.9.34-spdy-pc.patch (included upstream)
* Thu May  8 2014 meissner@suse.com
- do not define test_data before system header inclusion, libgcrypt
  uses this as argument parameters. (libmicrohttpd_test_data.patch)
* Mon Apr 28 2014 coolo@suse.com
- disable problematic test case that causes the testsuite to deadlock
  just too often (disable-stalling-test.patch)
* Thu Apr 24 2014 dmueller@suse.com
- remove dependency on gpg-offline, source validator already
  does that
* Mon Apr 21 2014 tchvatal@suse.com
- Version bump to 0.9.34:
  * Drop tls patch seems to build fine
  * Remove code for other distros we build against 13.1+ anywhere
    within obs and it just clutters the spec.
  * Explicitely name switches in configure to make sure things go
    the desired way.
  * Fix install of libmicrohttpspdy pc file.
  + Added support for TCP FASTOPEN.
  + Removed dependency on plibc for simpler compilation for W32.
  + Added configure option "--disable-pipes" to use socketpairs
    instead of pipes for signalling to child threads. Pipes are
    always disabled on W32.
  + Corrected some uses of 'int' vs. 'size_t'.
  + MHD_USE_DUAL_STACK in libmicrohttpd currently just *inhibits
    setting* the IPV6_V6ONLY socket option, but per Microsoft's
    documentation the default on Windows is that this is enabled, thus
    MHD_USE_DUAL_STACK will not work (since it leaves the
    default). libmicrohttpd should probably just unconditionally set
    IPV6_V6ONLY to the desired value when the option is available.
  + Allow Keep-Alive with HTTP 1.0 (if explicitly requested),
    and automatically set "Connection: Keep-Alive" in response
    in this case as well.
  + Adding explicit annotations to hide symbols that are not for
    export in the C code (gcc 4.0 or higher only).
  + Adding a few lines to avoid warnings from picky compilers.
- Added patches:
  * libmicrohttpd-0.9.34-spdy-pc.patch
- Dropped patches:
  * libmicrohttpd-drop-test_tls_options.patch
* Tue Mar  4 2014 coolo@suse.com
- do not run checks in parallel - they deadlock from time to time
- enable make debug to debug the problem on OBS in case it reappears
* Mon Jan 27 2014 sleep_walker@suse.cz
- refresh libmicrohttpd-drop-test_tls_options.patch
  - add there also ignoring test_https_sni
- Update to 0.9.33 bsc#854443 CVE-2013-7038 CVE-2013-7039
  + Fixed an issue with a missing argument in the postexample.
  + Fixed issue with bogus offset increment involving sendfile on
    GNU/Linux.  Adding support for SNI.
  + Fix for per-worker daemon pipes enabled with
    MHD_USE_SUSPEND_RESUME that were not closed in MHD_stop_daemon.
  + Fixing warnings and build issue if --disable-https is given to
    configure.
  +
  0.9.32:
  + Security fix: do not read past 0-terminator when unescaping
    strings (thanks to Florian Weimer for reporting).
  + Signaling n times for shutdown works, but for resume we need to
    wake up the correct daemon. Even if we signal n times in
    that case also, there's no guarantee that some daemon can't
    run through its select loop more than once before the
    daemon we want to wake up gets a chance to read.  Thus we
    need a signal pipe per thread in the thread pool IF
    MHD_suspend_connection is used.  This introduces a new flag
    MHD_USE_SUSPEND_RESUME to add those additional pipes and
    only allow MHD_suspend_connection to be used in conjunction
    with this flag.
    Also, as MHD_resume_connection() will be called on a
    non-daemon thread, but none of the queue insert/delete
    calls are thread safe, we need to be concerned about (a)
    corrupting the queue, and (b) having to add mutex
    protection around every access to the queues, including
    loops through timer queues, etc. This wasn't a problem
    before adding resume; even suspend should be safe since it
    happens in a callback from the daemon.
    I think it's easier to (a) have MHD_suspend_connection() move
    the connection to a suspended queue, (b) have
    MHD_resume_connection() mark the connection as resuming,
    and then (c) do all the actual queue manipulations in
    MHD_select (poll, epoll, etc.) to move the resumed
    connections back to their normal queues, in response to the
    wake up. The changes are simpler & cleaner. There is a cost
    to the basic select loop that is avoided by making
    suspend/resume a startup option. The per-worker pipes can
    then also be enabled only with that option set.
  + Eliminating theoretical stack overflow by limiting length
    of URIs in authentication headers to 32k (only applicable
    if the application explicitly raised the memroy limits,
    and only applies to MHD_digest_auth_check). Issue was
    reported by Florian Weimer.
  + Fix race on shutdown signal with thread pool on non-Linux
    systems by signalling n times for n threads.
  + Introduce state to mark connections in suspended state (with
    epoll); add missing locking operations in MHD_suspend_connection.
  + Fix definition of MHD_TLS_CONNECTION_INIT.
  + Fixing issue in PostProcessor when getting partial boundary
    at the beginning, expanding test suite.
  + Implementing faster processing of upload data in multipart
    encoding (thanks to performance analysis by Adam Homolya).
  + Adding support for connection flow control via
    MHD_suspend_connection and MHD_resume_connection.
  0.9.31:
  + Fixing build issues on OS X with CLOCK_MONOTONIC not being
    implemented on OS X.
  + Make libmicrohttpd play nicely with upcoming libgcrypt 1.6.0.
  + Improved configure checks for cURL.
  + Signal connection termination as OK (and not as ERROR) if the
    stream was terminated by the callback returning
    MHD_CONTENT_READER_END_OF_STREAM. Also, release response
    mutex before calling the termination callback, to avoid
    possible deadlock if the client destroys the response in
    the termination callback (due to non-recursiveness of the
    lock).
  + Adding #define MHD_HTTP_HEADER_ACCESS_CONTROL_ALLOW_ORIGIN.
  + Also pass MHD connection handle in URI log callback.
  + Improved check for proper OpenSSL version for
    libmicrospdy.
  + Set IPV6_V6ONLY socket option correctly when IPv6 is
    enabled (MHD_USE_IPv6) but not dual stack
    (MHD_USE_DUAL_STACK)
* Thu Oct  3 2013 mvyskocil@suse.com
- Update to 0.9.30
  + implements the "SHOULD" clause of RFC 2616 section 8.1.4, which
    may reduce bandwidth consumption when clients cancel requests.
  + fixes build errors with various combinations of operating systems,
    libc versions, and configure flags.
  + fixes a use-after-free crash when using epoll() in combination with
    read errors
  0.9.29:
  + epoll can now also be used with SSL connections
  + following recent HTTP/1.1 clarfications, MHD no longer send
    a "Content-length" header in CONNECT responses.
  + the "MHD_add_connection" call now consistently sets an "errno"
    value to indicate the cause of errors.
    Connections added this way are now always processed immediately.
  + fixes a recently-introduced bug which prevented HTTP pipelining
    from working properly in some cases and a build error in
    conjunction with the "--disable-messages" configure option.
- Enable build of (experimental) SPDY support.
* Wed Jul 24 2013 mvyskocil@suse.com
- Update to 0.9.28
  + support for epoll-based event loops (Linux-only)
  + various new options:
  - MHD_USE_DUAL_STACK for binding to IPv4 and IPv6 at the same time
  - MHD_USE_PIPE_FOR_SHUTDOWN to cleanly support MHD_quiesce_daemon on
    non-Linux systems
  - MHD_CONNECTION_INFO_CONNECTION_FD to allow COMET applications to
    disable TCP Nagle
  - MHD_OPTION_CONNECTION_MEMORY_INCREMENT for better control over
    buffer size allocations
  + and fixes various minor bugs
* Thu Jun  6 2013 mvyskocil@suse.com
- drop test_tls_options if build is in OBS
  libmicrohttpd-drop-test_tls_options.patch
* Wed Jun  5 2013 jengelh@inai.de
- More robust make install call
- Remove redundant %%clean section
- Requires(pre) is useless without a %%pre script
* Thu May 16 2013 mvyskocil@suse.com
- Update to 0.9.27
  + performance improvements for POST processing
  + new API call to reduce the number of select calls (if in "external"
    select mode)
  + new function to allow applications to stop MHD from processing new
    incoming connections while finishing ongoing requests
  + fixes an initialization problem on some platforms
  + fixes bug in the postprocessor's URL parser.
  + SSL connections are no longer dropped if the system uptime is less
    than the connection timeout
  + allows creating responses with zero bytes using
    MHD_create_response_from_callback.
  + few "const" statements have been added to allow keeping more static
    strings in ROM.
  + post processor now tolerates uploads which don't contain "\r\n" and
    also returns keys which don't have a matching value
  + fixes the loss of a parameter in processing POST data from IE8 and
    Chrome. It automatically sets a "Connection: close" header if the
    client requests the connection to be closed. Finally, given both
    'chunked' encoding and 'content-length', MHD now ignores the
    'content-length' header as per the RFC
  + adds support for building libmicrohttpd for Android
  + fixes an issue with data in TLS buffers sometimes not being completely
    drained if there was no activity on the socket.
- reenabled tests and moved to %%check
- add source verification using gpg
* Wed Oct  3 2012 fcrozat@suse.com
- Add copyright header to specfile.
* Fri Sep 28 2012 fcrozat@suse.com
- Update to 0.9.22:
  + Allow to configure basic and digest authentication separately
  + Fix URI argument parsing when string contained keys without
    equals sign in middle of the argument.
  + Reduce default size in poft processor buffer.
- Remove --enable-client-side from configure call, it doesn't exist
  anymore.
- Update License tag to new SPDX format.
* Fri Aug 10 2012 bitshuffler@opensuse.org
- Updated to 0.9.21
* Sun Feb  5 2012 bitshuffler@opensuse.org
- Updated to 0.9.19
* Sun Nov 27 2011 bitshuffler@opensuse.org
- Updated to 0.9.17
* Sat Nov 12 2011 bitshuffler@opensuse.org
- Updated to 0.9.16
* Sun Oct 16 2011 bitshuffler@opensuse.org
- Updated to 0.9.15
* Sat May 21 2011 bitshuffler@opensuse.org
- Updated to 0.9.11
* Fri Apr 29 2011 bitshuffler@opensuse.org
- Updated to 0.9.10
* Wed Mar 30 2011 bitshuffler@opensuse.org
- Updated to 0.9.9
* Sat Mar  5 2011 bitshuffler@opensuse.org
- Updated to 0.9.8
* Tue Feb 15 2011 bitshuffler@opensuse.org
- Updated to 0.9.7
* Thu Jan 27 2011 bitshuffler@opensuse.org
- Updated to 0.9.6
* Sat Jan 15 2011 bitshuffler@opensuse.org
- Updated to 0.9.5
* Wed Dec 29 2010 bitshuffler@opensuse.org
- Updated to 0.9.4
* Wed Nov 24 2010 bitshuffler@opensuse.org
- Updated to 0.9.3
* Thu Oct 21 2010 bitshuffler@opensuse.org
- Updated to 0.9.2
* Mon Sep 20 2010 bitshuffler@opensuse.org
- Updated to 0.9.1
* Tue Jul 27 2010 bitshuffler@opensuse.org
- Updated to 0.9.0
* Mon Mar 15 2010 pascal.bleser@opensuse.org
- update to 0.4.6:
  * fixes use of poll causing busy waiting
  * fixes a segfault if inconsistent options were used
  * fixes SSL support on big-endian architectures
  * fixes an issue with error signalling for PUT/POST requests in HTTP 1.1
* Tue Feb  2 2010 bitshuffler@opensuse.org
- Updated to 0.4.5.
* Sun Jan 17 2010 bitshuffler@opensuse.org
- Initial RPM.
